@@ -5,5 +5,8 @@
 #define HEADER_MAXSIZE 0x2000	/* maximum size for http header (stream cache) */
 #define CONNECTION_BUCKETS 100	/* number of buckets in connection hash table */
 
+/* memory limits */
+#define MAX_CONNECTIONS 1000	/* maximum number of simultaneous connections */
+
 /* global settings defined at runtime*/
 int debug;			/* debugging level */
