@@ -2,8 +2,8 @@
 #define CONN_H
 
 #include <netinet/in.h>
-#include <stdio.h>
 #include "config.h"
+#include "segment.h"
 #include "stream.h"
 
 /* connid holds all information required to identify a particular connection */
@@ -14,18 +14,10 @@ struct connid {
 	u_int16_t tcpdst;
 };
 
-/* holds a list of received fragments for a connection */
-struct fragment {
-	u_int32_t seq;
-	u_int32_t size;
-	u_char *data;
-	struct fragment *next;
-};
-
 /* holds a connection (each direction of a tcp session is a connection) */
 struct connection {
 	struct connid cid;
-	struct fragment *frags;
+	struct segment *segments;
 	u_int32_t seq;
 	u_int32_t size;
 	time_t time;
@@ -37,7 +29,7 @@ void connInit();
 void connKill();
 
 void connAdd(struct connid *cid, u_int32_t seq);
-void connDelete(struct connid *cid, u_int32_t seq);
+void connDelete(struct connid *cid, u_int32_t seq, u_char *data, u_int32_t len);
 void connData(struct connid *cid, u_int32_t seq, u_char *data, u_int32_t len);
 
 void connTwin(struct connid *twin, struct connid *cid);
