@@ -5,5 +5,5 @@ void hashDebug();
 
 struct connection *hashFind(struct connid *cid);
 struct connection *hashFindAll();
-void hashAdd(struct connection *conn);
+int hashAdd(struct connection *conn);
 struct connection *hashDelete(struct connid *cid);
