@@ -5,11 +5,6 @@
 #include <stdlib.h>
 #include "config.h"
 
-#define STREAM_UNKNOWN	0
-#define STREAM_SIMPLE	1
-#define STREAM_KEEP	2
-#define STREAM_CHUNK	3
-
 struct stream {
 	FILE *file;
 	u_char cache[HEADER_MAXSIZE + 1];
